---
title: The Standard Model of Particle Physics
...


The Standard Model of Particle Physics (SM) stands as one of the most predictive and insightful scientific theories ever written. It is the culmination of a hundred years of intense theoretical exploration and experimental tests. It can successfully explain phenomena ranging from nuclear decay and the structure of atoms to the behavior of cosmic ray showers. Included in the theory are three fundamental forces. The first and most familiar is the electromagnetic force which is mediated by the photon and which all particles with electric charge participate. The second is the strong nuclear force. The strong force is mediated by the gluon which controls the interaction between all *colored* particles. It is this force that is responsible for binding quarks together into mesons and baryons, as well as binding protons and neutrons together into atomic nuclei. Finally, the weak nuclear force, which is mediated by the W and Z bosons, and is responsible for nuclear $\beta$-decay as well as more exotic processes such as interactions with the ghostly neutrino particle and the decay of the top quark.

Notably, the Standard Model is completely unable to explain why apples fall from trees or why the earth orbits the sun since it lacks a description of the gravitational force. The current most complete theory of gravity is General Relativity. However, despite large and ongoing efforts to unite General Relativity with the Standard Model, no resulting theories have had the necessary self-consistency and predictive power to be accepted. Luckily for those working on collider experiments, the effect of gravity is so overwhelmed by the other three fundamental forces that it can be largely ignored. The constituent particles of the SM are shown in [@fig:sm_particles]. These particles are divided into several categories based on some fundamental properties.

# Fundamental Particles

The *fermions* are defined by their half-integer spin of $½\hbar$ and are split between the leptons and the quarks. They are fundamentally described as Dirac spinor fields which in the case of non-interacting massive particles are described by the Lagrangian

$$
\mathcal{L} = \bar{\psi}\left(i\partial\!\!\!/ - m\right)\psi
$$

in natural units, $\hbar=c=1$. The $\partial\!\!\!/$ operator is defined as $\gamma^\mu\partial_\mu$ in Einstein notation where $\gamma^\mu$ are the 4x4 $\gamma$-matrices that satisfy the anti-commutation relations $\left\{\gamma^\mu,\gamma^\nu\right\}=2\eta^{\mu\nu}$ and $\eta^{\mu\nu}$ is the Minkowski metric. Other fermions and interactions can be added to the theory with additional terms.

The leptons come in three generations with each generation having an electrically charged member and an electrically neutral member. The charged members are the electron, muon, and tauon (or simply tau), while the neutral members are their three corresponding neutrinos. The electrically charged leptons participate in the electromagnetic and weak interaction, while the neutrinos only participate in the weak interaction. Another feature of the leptons is that while the charged leptons have non-trivial masses, the neutrinos are nearly massless. In fact, they were originally believed to be massless, until the observation of neutrino-mixing implied that at least two of them must have mass. The quarks also come in three generations with two members in each generation. In contrast with the leptons, however, the quarks all carry electric charge. The "up-type" quarks carry charge $+2/3$ while the "down-type" quarks carry charge $-1/3$. The quarks are also *colored* which means that in addition to participating in the electromagnetic and weak interactions, they also interact via the *strong* nuclear force. Each of the six quarks has non-trivial mass, but they are wildly different, running from 2.4 $\mathrm{MeV}/\mathrm{c}^2$ for the up quark all the way to 171 $\mathrm{GeV}/\mathrm{c}^2$ for the top quark, the heaviest fundamental particle in the SM. 
The remaining particles are the bosons, four force-mediators and the Higgs. These will be discussed in the following sections in context with their respective forces and contributions to the SM.

![The particles of the SM](figures/theory/sm_particles.png){#fig:sm_particles}

# Quantum Electrodynamics

One of the early triumphs of quantum field theory was the description of electromagnetism developed by Tomonaga[@Tomonaga1946], Schwinger[@Schwinger1948], Feynman[@Feynman1949], and Dyson[@Dyson1949] and eventually coming to be known as quantum electrodynamics (QED). This theory describes the interaction of electrically charged particles with photons. In QED photons are described by a 4-vector field, $A^\mu$, which is used to define the field strength tensor $F^{\mu\nu} = \partial^\mu A^\nu - \partial^\nu A^\mu$. This field, in the absence of charged particles, is governed by the Maxwell Lagrangian

$$
\mathcal{L}_{\mathrm{Max}} = -\frac{1}{4}F^{\mu\nu}F_{\mu\nu}
$$

Fermion interactions are added with 

$$
\mathcal{L}_{\mathrm{Int}} = \bar{\psi}\left(iD\!\!\!\!/ - m\right)\psi + \mathrm{h.c.}
$$

Where $D\!\!\!\!/ \equiv \gamma^{\mu}\left(\partial_\mu + iqA_\mu\right)$ and h.c. is just the hermitian conjugate of the previous term. Putting these together yields the QED Lagrangian.

$$
\mathcal{L}_{\mathrm{QED}} = i\bar{\psi}\gamma^\mu\partial_\mu\psi - q\bar{\psi}\gamma^\mu A_\mu\psi - \frac{1}{4}F^{\mu\nu}F_{\mu\nu}
$$

QED is a gauge theory. This comes from the assumption that the observable is not the potential $A^\mu$, but only the fields it defines. This leads one to ask what transformations can be applied to $A^\mu$ that leave the fields invariant. These *gauge transformations* define symmetries of the field. In the language of group theory, QED has a $U(1)$ symmetry. The transformation associated with this symmetry that leaves $\mathcal{L}_{\mathrm{QED}}$ unchanged is:

$$
A^\mu \rightarrow A^\mu + \partial^\mu\chi, \psi \rightarrow e^{-iq\chi}\psi
$$


# Quantum Chromodynamics

The theory describing the interaction of colored particles is quantum chromodynamics (QCD). The only colored fermions, quarks, were first proposed by Gell-Mann[@GellMann1964] and Zweig[Zweig:1964jf] in 1964 to aide in the classification of hadrons, and were first observed four years later at SLAC[@Bloom1969]. In contrast with QED, QCD obeys the non-Abelian SU(3) symmetry. However, just as $A^\mu$ was used to define a field strength tensor in QED, the eight *gluon* fields each define their field strength tensor as

$$
G_{\mu\nu}^{a} = \partial_\mu G_\nu^a - \partial_\nu G_\mu^a - g_s f_{abc}G_\mu^b G_nu^c
$$

where $g_s$ is the strong coupling constant and the $f_{abc}$ are the structure constants of the symmetry group defined by the commutation relations

$$
\left[\frac{\lambda_a}{2},\frac{\lambda_b}{2}\right] = i f_{abc} \frac{\lambda_c}{2}
$$

where $\lambda_a$ are the Gall-Mann matrices. The quarks, similar to the fermions in QED, are represented as spinor fields governed by the Lagrangian

$$
\mathcal{L}_q = \bar{q_f}\left(i\gamma^{\mu}\partial_\mu - m\right)q_f
$$

for a single quark. In $\mathcal{L}_q$, $q_f = (\psi_1, \psi_2, \psi_3)$ where each $\psi$ represents a color components and there is an implied sum over all three. Interactions between the quarks and the gluons are introduced by introducing the covariant derivative $D_\mu$ into $\mathcal{L}_q$ in place of $\partial_mu$ where

$$
D_mu = \partial_\mu + ig_s\frac{\lambda_a}{2}G^a_\mu.
$$

Doing this yields the QCD Lagrangian.

$$
\mathcal{L}_\mathrm{QCD} = \sum_f \bar{q}_f\left(i\gamma^\mu\partial_\mu - m\right)q_f - \frac{1}{4}G_a^{\mu\nu}G^a_{mu\nu} - g_s \bar{q}_f \gamma^\mu \frac{\lambda_a}{2}q_f G^1_\mu
$$

The one-loop beta function for QCD in the Standard Model is

$$
\beta\left(g\right) = -\frac{7\alpha_s^2}{2\pi}
$$

The fact that the beta function is negative implies that the coupling decreases with energy scale. This leads to the property of asymptotic freedom. The fact that the coupling constant is small at high energies also means that one can successfully apply pertubation theory as one would in QED. However, at low energies, such as those of most bound states, perturbative approaches fail and other approaches, such as *Lattice QCD* are necessary. Quarks and gluons are also subject to color confinement, which means that any observable particle must be color neutral. This can be achieved by having equal quantities of the three colors, conventionally called red, blue, and green. Such is the case for *baryons*, with three quarks carrying one of each color charge. Color neutrality can also be achieved via a quark-antiquark pair possessing the same color, e.g. a green quark and an anti-green quark together make up a colorless *meson*. Colorless combinations of more than three quarks are possible, but not normally encountered. Colorless pairings of gluons, or *glueballs*, are also possible, but have not been observed experimentally.

# Electroweak Interaction

In 1934, Fermi proposed an explanation for nuclear beta decay, $n \rightarrow p e^- \bar{\nu_e}$[@Fermi1934]. This involved a new interaction will come to be identified as the weak nuclear force. This was initially proposed to be a point-like interaction, but over the next few decades experiments at higher energies would show that this was just a low energy approximation. In reality this process is mediated by a new force mediator, the W boson. This new particle was discovered at CERN in 1983 by the UA1[@Arnison1983] and UA2 experiments [@Banner1983]. Its mass is currently measured to be $80.379\pm 0.012\mathrm{GeV}/c^2$[@PhysRevD.98.030001].

![Leading order Feynman diagram for nuclear $\beta$ decay](figures/theory/beta_decay.png){#fig:beta_decay}




TODO: 
  - Electroweak interaction and Symmetry breaking, Higgs
  - Top quark phenomena

